==> zio-aws-pinpoint_3-5.17.104.12-sources.jar: zio/aws/pinpoint/model/VerifyOtpMessageRequest.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class VerifyOtpMessageRequest(
    applicationId: __string,
    verifyOTPMessageRequestParameters: zio.aws.pinpoint.model.VerifyOTPMessageRequestParameters
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.VerifyOtpMessageRequest = {
    import VerifyOtpMessageRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.VerifyOtpMessageRequest
      .builder()
      .applicationId(__string.unwrap(applicationId): java.lang.String)
      .verifyOTPMessageRequestParameters(
        verifyOTPMessageRequestParameters.buildAwsValue()
      )
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.VerifyOtpMessageRequest.ReadOnly =
    zio.aws.pinpoint.model.VerifyOtpMessageRequest.wrap(buildAwsValue())
}
object VerifyOtpMessageRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.VerifyOtpMessageRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.VerifyOtpMessageRequest =
      zio.aws.pinpoint.model.VerifyOtpMessageRequest(
        applicationId,
        verifyOTPMessageRequestParameters.asEditable
      )
    def applicationId: __string
    def verifyOTPMessageRequestParameters
        : zio.aws.pinpoint.model.VerifyOTPMessageRequestParameters.ReadOnly
    def getApplicationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(applicationId)
    def getVerifyOTPMessageRequestParameters: ZIO[
      Any,
      Nothing,
      zio.aws.pinpoint.model.VerifyOTPMessageRequestParameters.ReadOnly
    ] = ZIO.succeed(verifyOTPMessageRequestParameters)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.VerifyOtpMessageRequest
  ) extends zio.aws.pinpoint.model.VerifyOtpMessageRequest.ReadOnly {
    override val applicationId: __string =
      zio.aws.pinpoint.model.primitives.__string(impl.applicationId())
    override val verifyOTPMessageRequestParameters
        : zio.aws.pinpoint.model.VerifyOTPMessageRequestParameters.ReadOnly =
      zio.aws.pinpoint.model.VerifyOTPMessageRequestParameters
        .wrap(impl.verifyOTPMessageRequestParameters())
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.VerifyOtpMessageRequest
  ): zio.aws.pinpoint.model.VerifyOtpMessageRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-pinpoint_3-5.17.267.1-sources.jar: zio/aws/pinpoint/model/VerifyOtpMessageRequest.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class VerifyOtpMessageRequest(
    applicationId: __string,
    verifyOTPMessageRequestParameters: zio.aws.pinpoint.model.VerifyOTPMessageRequestParameters
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.VerifyOtpMessageRequest = {
    import VerifyOtpMessageRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.VerifyOtpMessageRequest
      .builder()
      .applicationId(applicationId: java.lang.String)
      .verifyOTPMessageRequestParameters(
        verifyOTPMessageRequestParameters.buildAwsValue()
      )
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.VerifyOtpMessageRequest.ReadOnly =
    zio.aws.pinpoint.model.VerifyOtpMessageRequest.wrap(buildAwsValue())
}
object VerifyOtpMessageRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.VerifyOtpMessageRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.VerifyOtpMessageRequest =
      zio.aws.pinpoint.model.VerifyOtpMessageRequest(
        applicationId,
        verifyOTPMessageRequestParameters.asEditable
      )
    def applicationId: __string
    def verifyOTPMessageRequestParameters
        : zio.aws.pinpoint.model.VerifyOTPMessageRequestParameters.ReadOnly
    def getApplicationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(applicationId)
    def getVerifyOTPMessageRequestParameters: ZIO[
      Any,
      Nothing,
      zio.aws.pinpoint.model.VerifyOTPMessageRequestParameters.ReadOnly
    ] = ZIO.succeed(verifyOTPMessageRequestParameters)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.VerifyOtpMessageRequest
  ) extends zio.aws.pinpoint.model.VerifyOtpMessageRequest.ReadOnly {
    override val applicationId: __string = impl.applicationId(): __string
    override val verifyOTPMessageRequestParameters
        : zio.aws.pinpoint.model.VerifyOTPMessageRequestParameters.ReadOnly =
      zio.aws.pinpoint.model.VerifyOTPMessageRequestParameters
        .wrap(impl.verifyOTPMessageRequestParameters())
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.VerifyOtpMessageRequest
  ): zio.aws.pinpoint.model.VerifyOtpMessageRequest.ReadOnly = new Wrapper(impl)
}
